The reasonable package offers a library, binary and Python bindings for performing OWL 2 RL
reasoning on RDF graphs. This package implements the Datalog rules as communicated on the W3C
OWL2
Profile
website.
The reasonable package offers a library, binary and Python bindings for performing OWL 2 RL
reasoning on RDF graphs. This package implements the Datalog rules as communicated on the W3C
OWL2
Profile
website.